@@ -1,8 +1,10 @@
 #' Pull covid19india national time series data
 #' @param path The URL path for the data. Default: https://api.covid19india.org/csv/latest/case_time_series.csv
-#' @param raw Pull raw unaltered data. Default is FALSE
+#' @param raw Pull raw unaltered data. Default is `FALSE`
+#' @param corr_check Check for data correction. Default is `FALSE`
 #' @return Pulls the time-series case, death, and recovered data directly from covid19india.org.
-#' @import tidyverse
+#' @import dplyr
+#' @importFrom readr read_csv
 #' @importFrom janitor clean_names
 #' @export
 #' @examples
@@ -13,7 +15,8 @@
 
 get_nat_counts <- function(
   path       = "https://api.covid19india.org/csv/latest/case_time_series.csv",
-  raw        = FALSE
+  raw        = FALSE,
+  corr_check = FALSE
 ) {
 
   d <- readr::read_csv(path,
@@ -38,6 +41,18 @@ get_nat_counts <- function(
 
   }
 
+  if (corr_check == TRUE) {
+
+    if (raw == TRUE) {
+      stop("`raw` must be FALSE to use `corr_check = TRUE` argument")
+    } else {
+
+    d <- d %>%
+      covid19india::check_for_data_correction(var = "daily_cases")
+
+    }
+  }
+
   return(d)
 
 }
